@@ -1,8 +1,15 @@
-wnet.perm <- function(y, xfuncs, min.scale = 0, nfeatures = NULL, alpha = 1, lambda = NULL, covt = NULL, 
-                      nrep = 1, nsplit=1, nfold = 5, nperm = 20, 
-                      perm.method = c("responses", "y.residuals", "x.residuals"),
-                      family = "gaussian", seed.real=NULL, seed.perm=NULL, ...){
-    perm.method = match.arg(perm.method)
+wnet.perm <- function(y, xfuncs, min.scale = 0, nfeatures = NULL, alpha = 1, lambda = NULL, 
+                      covt = NULL, nrep = 1, nsplit=1, nfold = 5, nperm = 20, 
+                      perm.method = NULL, family = "gaussian", seed.real=NULL, seed.perm=NULL, ...){
+    if (is.null(perm.method)){
+    	if (is.null(covt)){
+    		perm.method = "responses"
+    	} else if (family == 'gaussian'){
+    		perm.method = 'y.residuals'
+    	} else if (family == 'binomial'){
+    		perm.method = 'x.residuals'
+    	}
+    }
     if (is.null(covt) && perm.method == "x.residuals"){
     	stop("'x.residuals' method is unavailable when 'covt' is NULL.")
     }
@@ -20,7 +27,7 @@ wnet.perm <- function(y, xfuncs, min.scale = 0, nfeatures = NULL, alpha = 1, lam
     if (perm.method == "y.residuals") {
         obje <- wnet(y = y, xfuncs = xfuncs, min.scale = min.scale, nfeatures = nfeatures, alpha = alpha, 
                      lambda = lambda, covt = covt, family = family, nsplit = nsplit, ...)
-        y.resid <- obje$fitted - y
+        y.resid <- y - obje$fitted
     }  else if (perm.method == "x.residuals") {
     	X = as.matrix(covt)
     	Y = matrix(xfuncs, nrow = length(y))
